import { ProCard } from '@ant-design/pro-components';
import { Menu, MenuProps } from 'antd';
import { useState } from 'react';
import { generateToken } from '@/tools/token';

// 内网地址
// const domain = `https://172.16.107.4:8000`;
// 价值平台地址
const domain = `https://10.170.42.195:8000`;

type MenuItem = Required<MenuProps>['items'][number];

const items1: MenuItem[] = [
    {
        key: '不动产专题',
        label: '不动产专题',
        children: [
            { key: '不动产运营报告', label: '不动产运营报告' },
            { key: '不动产资源地图', label: '资源地图' },
            { key: '一房产局址一表', label: '一房产局址一表' },
            {
                key: '不动产资源',
                label: '不动产资源',
                children: [
                    { key: '房屋管理', label: '房屋管理' },
                    { key: '土地管理', label: '土地管理' },
                    { key: '数据稽查', label: '数据稽查' },
                ],
            },
            {
                key: '不动产运营',
                label: '不动产运营',
                children: [
                    { key: '房屋对外出租', label: '房屋对外出租' },
                    { key: '房屋租入', label: '房屋租入' },
                    { key: '房屋维修', label: '房屋维修' },
                ],
            },
            { key: '综合评价', label: '综合评价' },
            {
                key: '不动产管理策略',
                label: '不动产管理策略',
                children: [
                    { key: '房屋空置', label: '房屋空置' },
                    { key: '维修异常监控', label: '维修异常监控' },
                    { key: '出租监控', label: '出租监控' },
                ],
            },
            {
                key: '不动产基础信息维护',
                label: '基础信息维护',
                children: [
                    { key: '负责人信息维护', label: '负责人信息维护' },
                    { key: '不动产策略公式维护', label: '策略公式维护' },
                ],
            },
        ],
    },
];

const items2: MenuItem[] = [
    {
        key: '车辆专题',
        label: '车辆专题',
        children: [
            { key: '车辆运营报告', label: '车辆运营报告' },
            { key: '车辆资源地图', label: '资源地图' },
            { key: '一车一表', label: '一车一表' },
            {
                key: '车辆费用',
                label: '车辆费用',
                children: [
                    { key: '车辆总费用', label: '车辆总费用' },
                    { key: '百公里费用', label: '百公里费用' },
                    { key: '租赁车辆费用', label: '租赁车辆费用' },
                    { key: '自有车辆费用', label: '自有车辆费用' },
                ],
            },
            {
                key: '车辆效能',
                label: '车辆效能',
                children: [
                    { key: '总体效能', label: '总体效能' },
                    { key: '低效车辆', label: '低效车辆' },
                ],
            },
            {
                key: '行车安全',
                label: '行车安全',
                children: [
                    { key: '派单管理', label: '派单管理' },
                    { key: '违章处理', label: '违章处理' },
                    { key: '年检情况', label: '年检情况' },
                    { key: '保养情况', label: '保养情况' },
                ],
            },
            {
                key: '车辆管理策略',
                label: '车辆管理策略',
                children: [
                    { key: '费用探针', label: '费用探针' },
                    { key: '效能探针', label: '效能探针' },
                    { key: '行驶探针', label: '行驶探针' },
                ],
            },
            {
                key: '车辆基础信息维护',
                label: '基础信息维护',
                children: [
                    { key: '车辆信息维护', label: '车辆信息维护' },
                    { key: '特殊车辆维护', label: '特殊车辆维护' },
                    { key: '车辆策略公式维护', label: '策略公式维护' },
                ],
            },
        ],
    },
];

const generateUrl = (key: string) => {
    const token = generateToken();
    if ('不动产运营报告' === key) {
        return `${domain}/house-car/house/report/#/?data=${token}`;
    }

    if ('不动产资源地图' === key) {
        return `${domain}/house-car/house/resource-map/#/?data=${token}`;
    }

    if ('一房产局址一表' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/overview?data=${token}`;
    }

    if ('房屋管理' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/house/fangmenu1-4?data=${token}`;
    }

    if ('土地管理' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/house/fangmenu1-5?data=${token}`;
    }

    if ('数据稽查' === key) {
        return `${domain}/house-car/house/data-check/#/?data=${token}`;
    }

    if ('房屋对外出租' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/pingjia/pingmenu1-1?data=${token}`;
    }

    if ('房屋租入' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/pingjia/pingmenu1-21?data=${token}`;
    }

    if ('房屋维修' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/pingjia/pingmenu1-4?data=${token}`;
    }

    if ('综合评价' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/evaluation?data=${token}`;
    }

    if ('房屋空置' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/yubao/yumenu?data=${token}`;
    }

    if ('维修异常监控' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/yubao/yumenu2?data=${token}`;
    }

    if ('出租监控' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/yubao/pingmenu1-8?data=${token}`;
    }

    if ('负责人信息维护' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/jichu/jiyumenu-1?data=${token}`;
    }

    if ('不动产策略公式维护' === key) {
        return `${domain}/house-car/house/dist/index.html#/administrative/jichu/jiyumenu-2?data=${token}`;
    }

    if ('车辆运营报告' === key) {
        return `${domain}/house-car/car/report/#/?data=${token}`;
    }

    if ('车辆资源地图' === key) {
        return `${domain}/house-car/car/resource-map/#/?data=${token}`;
    }

    if ('一车一表' === key) {
        return `${domain}/house-car/car/car/default/table?data=${token}`;
    }

    if ('车辆总费用' === key) {
        return `${domain}/house-car/car/car/fee/total?data=${token}`;
    }

    if ('百公里费用' === key) {
        return `${domain}/house-car/car/car/fee/miles100?data=${token}`;
    }

    if ('租赁车辆费用' === key) {
        return `${domain}/house-car/car/car/fee/rental?data=${token}`;
    }

    if ('自有车辆费用' === key) {
        return `${domain}/house-car/car/car/fee/owning?data=${token}`;
    }

    if ('总体效能' === key) {
        return `${domain}/house-car/car/car/eff/total?data=${token}`;
    }

    if ('低效车辆' === key) {
        return `${domain}/house-car/car/car/eff/low?data=${token}`;
    }

    if ('派单管理' === key) {
        return `${domain}/house-car/car/car/safety/dispatch?data=${token}`;
    }

    if ('违章处理' === key) {
        return `${domain}/house-car/car/car/safety/violation?data=${token}`;
    }

    if ('年检情况' === key) {
        return `${domain}/house-car/car/car/safety/annually?data=${token}`;
    }

    if ('保养情况' === key) {
        return `${domain}/house-car/car/car/safety/maintain?data=${token}`;
    }

    if ('费用探针' === key) {
        return `${domain}/house-car/car/car/probe/cost?data=${token}`;
    }

    if ('效能探针' === key) {
        return `${domain}/house-car/car/car/probe/efficiency?data=${token}`;
    }

    if ('行驶探针' === key) {
        return `${domain}/house-car/car/car/probe/driving?data=${token}`;
    }

    if ('车辆信息维护' === key) {
        return `${domain}/house-car/car/car/baseinfo/fuzeren?data=${token}`;
    }

    if ('特殊车辆维护' === key) {
        return `${domain}/house-car/car/car/baseinfo/specar?data=${token}`;
    }

    if ('车辆策略公式维护' === key) {
        return `${domain}/house-car/car/car/baseinfo/celue?data=${token}`;
    }

    return undefined;
};

export default () => {
    const [stateOpenKeys1, setStateOpenKeys1] = useState([
        '不动产专题',
        '不动产资源',
        '不动产运营',
        '不动产管理策略',
        '不动产基础信息维护',
    ]);

    const [stateOpenKeys2, setStateOpenKeys2] = useState([
        '车辆专题',
        '车辆费用',
        '车辆效能',
        '行车安全',
        '车辆管理策略',
        '车辆基础信息维护',
    ]);

    const onClick = (info: any) => {
        const url = generateUrl(info.key);
        if (url) {
            window.open(url, '_blank', 'noopener,noreferrer');
        }
    };

    return (
        <ProCard>
            <ProCard layout={"center"}>
                <Menu
                    mode="inline"
                    openKeys={stateOpenKeys1}
                    onOpenChange={(openKeys) => setStateOpenKeys1(openKeys)}
                    items={items1}
                    style={{ width: 256 }}
                    onClick={onClick}
                />
            </ProCard>
            <ProCard layout={"center"}>
                <Menu
                    mode="inline"
                    openKeys={stateOpenKeys2}
                    onOpenChange={(openKeys) => setStateOpenKeys2(openKeys)}
                    items={items2}
                    style={{ width: 256 }}
                    onClick={onClick}
                />
            </ProCard>
        </ProCard>
    );
};
